@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,7 +15,6 @@
  */
 package ghidra.app.util.pdb.pdbapplicator;
 
-import java.io.IOException;
 import java.util.*;
 
 import ghidra.app.util.bin.format.pdb2.pdbreader.*;
@@ -71,24 +70,28 @@ public class PdbAddressManager {
 
 	private PdbAddressCalculator addressCalculator;
 
+	private boolean isInitialized;
 	//==============================================================================================
 	// API
 	//==============================================================================================
+
+	public PdbAddressManager() {
+		isInitialized = false;
+	}
+
 	/**
 	 * Manager
-	 * @param applicator {@link DefaultPdbApplicator} for which this class is working.
-	 * @param imageBase Address from which all other addresses are based.
+	 * @param applicatorArg {@link DefaultPdbApplicator} for which this class is working.
+	 * @param imageBaseArg Address from which all other addresses are based.
 	 * @throws PdbException If Program is null;
 	 * @throws CancelledException upon user cancellation
-	 * @throws IOException on file seek or read, invalid parameters, bad file configuration, or
-	 *  inability to read required bytes
 	 */
-	PdbAddressManager(DefaultPdbApplicator applicator, Address imageBase)
-			throws PdbException, CancelledException, IOException {
-		Objects.requireNonNull(applicator, "applicator may not be null");
-		Objects.requireNonNull(imageBase, "imageBase may not be null");
-		this.applicator = applicator;
-		this.imageBase = imageBase;
+	void initialize(DefaultPdbApplicator applicatorArg, Address imageBaseArg)
+			throws PdbException, CancelledException {
+		Objects.requireNonNull(applicatorArg, "applicator may not be null");
+		Objects.requireNonNull(imageBaseArg, "imageBase may not be null");
+		this.applicator = applicatorArg;
+		this.imageBase = imageBaseArg;
 		memoryGroupRefinement = new ArrayList<>();
 		memorySectionRefinement = new ArrayList<>();
 
@@ -103,6 +106,15 @@ public class PdbAddressManager {
 //		determineMemoryBlocks_orig();
 		mapPreExistingSymbols();
 		createAddressRemap();
+		isInitialized = true;
+	}
+
+	/**
+	 * Returns {@code true} if already initialized
+	 * @return {@code true}" if initialized
+	 */
+	boolean isInitialized() {
+		return isInitialized;
 	}
 
 	/**
@@ -342,13 +354,13 @@ public class PdbAddressManager {
 	/**
 	 * Determines memory blocks
 	 * @throws CancelledException upon user cancellation
-	 * @throws PdbException upon error in processing components
-	 * @throws IOException on file seek or read, invalid parameters, bad file configuration, or
-	 *  inability to read required bytes
 	 */
-	private void determineMemoryBlocks() throws CancelledException, PdbException, IOException {
+	private void determineMemoryBlocks() throws CancelledException {
 		AbstractPdb pdb = applicator.getPdb();
 		PdbDebugInfo debugInfo = pdb.getDebugInfo();
+		if (debugInfo == null) {
+			return;
+		}
 		segmentMapList = debugInfo.getSegmentMapList();
 		if (debugInfo instanceof PdbNewDebugInfo) {
 			DebugData debugData = ((PdbNewDebugInfo) debugInfo).getDebugData();
@@ -427,7 +439,7 @@ public class PdbAddressManager {
 	}
 
 	/**
-	 * Write the mapped address for a query address, where where the mapping is
+	 * Write the mapped address for a query address, where the mapping is
 	 *  derived by using a the address of a PDB symbol as the key and finding the address of
 	 *  a symbol in the program of the same "unique" name. This is accomplished using public
 	 *  mangled symbols.  If the program symbol came from the PDB, then it maps to itself.
